[][src]Enum pgn_reader::Rank

#[repr(i8)]
pub enum Rank { First, Second, Third, Fourth, Fifth, Sixth, Seventh, Eighth, }

A rank of the chessboard.

Variants

FirstSecondThirdFourthFifthSixthSeventhEighth

Methods

impl Rank[src]

pub fn new(index: i8) -> Rank[src]

Gets a Rank from an integer index.

Panics

Panics if the index is not in the range 0..=7.

pub fn from_char(ch: char) -> Option<Rank>[src]

pub fn from_index(index: i8) -> Option<Rank>[src]

pub unsafe fn from_index_unchecked(index: i8) -> Rank[src]

Gets a Rank from an integer index.

Unsafety

It is the callers responsibility to ensure the index is in the range 0..=7.

pub fn char(self) -> char[src]

pub fn flip_diagonal(self) -> File[src]

pub fn offset(self, delta: i8) -> Option<Rank>[src]

pub fn flip_vertical(self) -> Rank[src]