[−][src]Enum pgn_reader::San
A move in Standard Algebraic Notation.
Variants
NormalFields of Normal
Castle(CastlingSide)PutFields of Put
NullMethods
impl San[src]
pub fn from_ascii(san: &[u8]) -> Result<San, ParseSanError>[src]
Parses a SAN. Ignores a possible check or checkmate suffix.
Errors
Returns ParseSanError if san is not syntactically valid.
pub fn from_move<P>(pos: &P, m: &Move) -> San where
P: Position, [src]
P: Position,
Converts a move to Standard Algebraic Notation.
pub fn to_move<P>(&self, pos: &P) -> Result<Move, SanError> where
P: Position, [src]
P: Position,
Tries to convert the San to a legal move in the context of a
position.
Errors
Returns SanError if there is no unique matching legal move.
pub fn disambiguate(m: &Move, moves: &ArrayVec<[Move; 512]>) -> San[src]
pub fn find_move(
&self,
moves: &'a ArrayVec<[Move; 512]>
) -> Result<&'a Move, SanError>[src]
&self,
moves: &'a ArrayVec<[Move; 512]>
) -> Result<&'a Move, SanError>
Searches a MoveList for a unique matching move.
Errors
Returns SanError if there is no unique matching legal move.
pub fn matches(&self, m: &Move) -> bool[src]
Test if the San can match the Move (in any position).
Examples
use shakmaty::{Square, Role, Move}; use shakmaty::san::San; let m = Move::Normal { role: Role::Knight, from: Square::G1, to: Square::F3, capture: None, promotion: None, }; let nf3 = San::from_ascii(b"Nf3")?; assert!(nf3.matches(&m)); let ng1f3 = San::from_ascii(b"Ng1f3")?; assert!(ng1f3.matches(&m)); // capture does not match let nxf3 = San::from_ascii(b"Nxf3")?; assert!(!nxf3.matches(&m)); // other file does not match let nef3 = San::from_ascii(b"Nef3")?; assert!(!nef3.matches(&m));