[−][src]Enum pgn_reader::Square
A square index.
Variants
A1B1C1D1E1F1G1H1A2B2C2D2E2F2G2H2A3B3C3D3E3F3G3H3A4B4C4D4E4F4G4H4A5B5C5D5E5F5G5H5A6B6C6D6E6F6G6H6A7B7C7D7E7F7G7H7A8B8C8D8E8F8G8H8Methods
impl Square[src]
pub fn new(index: i8) -> Square[src]
Gets a Square from an integer index.
Panics
Panics if the index is not in the range 0..=63.
Examples
use shakmaty::Square; assert_eq!(Square::new(0), Square::A1); assert_eq!(Square::new(63), Square::H8);
pub fn from_index(index: i8) -> Option<Square>[src]
Tries to get a Square from an integer index in the range 0..=63.
Examples
use shakmaty::Square; assert_eq!(Square::from_index(0), Some(Square::A1)); assert_eq!(Square::from_index(63), Some(Square::H8)); assert_eq!(Square::from_index(64), None);
pub unsafe fn from_index_unchecked(index: i8) -> Square[src]
Gets a Square from an integer index.
Unsafety
It is the callers responsibility to ensure it is in the range 0..=63.
pub fn from_coords(file: File, rank: Rank) -> Square[src]
Tries to get a square from file and rank.
Examples
use shakmaty::{Square, File, Rank}; assert_eq!(Square::from_coords(File::A, Rank::First), Square::A1);
pub fn from_ascii(s: &[u8]) -> Result<Square, ParseSquareError>[src]
Parses a square name.
Errors
Returns ParseSquareError if the input is not a valid square name
in lowercase ASCII characters.
Example
use shakmaty::Square; let sq = Square::from_ascii(b"a5")?; assert_eq!(sq, Square::A5);
pub fn file(self) -> File[src]
Gets the file.
Examples
use shakmaty::{Square, File}; assert_eq!(Square::A1.file(), File::A); assert_eq!(Square::B2.file(), File::B);
pub fn rank(self) -> Rank[src]
Gets the rank.
Examples
use shakmaty::{Square, Rank}; assert_eq!(Square::A1.rank(), Rank::First); assert_eq!(Square::B2.rank(), Rank::Second);
pub fn coords(self) -> (File, Rank)[src]
Gets file and rank.
Examples
use shakmaty::{Square, File, Rank}; assert_eq!(Square::A1.coords(), (File::A, Rank::First)); assert_eq!(Square::H8.coords(), (File::H, Rank::Eighth));
pub fn offset(self, delta: i8) -> Option<Square>[src]
Calculates the offset from a square index.
Examples
use shakmaty::Square; assert_eq!(Square::F3.offset(8), Some(Square::F4)); assert_eq!(Square::F3.offset(-1), Some(Square::E3)); assert_eq!(Square::F3.offset(48), None);
pub fn flip_horizontal(self) -> Square[src]
Flip the square horizontally.
use shakmaty::Square; assert_eq!(Square::H1.flip_horizontal(), Square::A1); assert_eq!(Square::D3.flip_horizontal(), Square::E3);
pub fn flip_vertical(self) -> Square[src]
Flip the square vertically.
use shakmaty::Square; assert_eq!(Square::A8.flip_vertical(), Square::A1); assert_eq!(Square::D3.flip_vertical(), Square::D6);
pub fn flip_diagonal(self) -> Square[src]
Flip at the a1-h8 diagonal by swapping file and rank.
use shakmaty::Square; assert_eq!(Square::A1.flip_diagonal(), Square::A1); assert_eq!(Square::A3.flip_diagonal(), Square::C1);
pub fn is_light(self) -> bool[src]
Tests is the square is a light square.
use shakmaty::Square; assert!(Square::D1.is_light()); assert!(!Square::D8.is_light());
pub fn is_dark(self) -> bool[src]
Tests is the square is a dark square.
use shakmaty::Square; assert!(Square::E1.is_dark()); assert!(!Square::E8.is_dark());
pub fn distance(self, other: Square) -> i8[src]
The distance between the two squares, i.e. the number of king steps to get from one square to the other.
use shakmaty::Square; assert_eq!(Square::A2.distance(Square::B5), 3);
pub fn combine(self, rank: Square) -> Square[src]
Combines two squares, taking the file from the first and the rank from the second.
use shakmaty::Square; assert_eq!(Square::D3.combine(Square::F5), Square::D5);