[−][src]Struct pgn_reader::BufferedReader
A buffered PGN reader.
Methods
impl<T: AsRef<[u8]>> BufferedReader<Cursor<T>>[src]
pub fn new_cursor(inner: T) -> BufferedReader<Cursor<T>>[src]
Create a new reader by wrapping a byte slice in a Cursor.
use pgn_reader::BufferedReader; let pgn = b"1. e4 e5 *"; let reader = BufferedReader::new_cursor(&pgn[..]);
impl<R: Read> BufferedReader<R>[src]
pub fn new(inner: R) -> BufferedReader<R>[src]
Create a new buffered PGN reader.
use std::fs::File; use pgn_reader::BufferedReader; let file = File::open("example.pgn")?; let reader = BufferedReader::new(file);
pub fn read_game<V: Visitor>(
&mut self,
visitor: &mut V
) -> Result<Option<V::Result>>[src]
&mut self,
visitor: &mut V
) -> Result<Option<V::Result>>
Read a single game, if any, and returns the result produced by the visitor.
Errors
- I/O error from the underlying reader.
- Irrecoverable parser errors.
pub fn skip_game<V: Visitor>(&mut self) -> Result<bool>[src]
Skip a single game, if any.
Errors
- I/O error from the underlying reader.
- Irrecoverable parser errors.
pub fn read_all<V: Visitor>(&mut self, visitor: &mut V) -> Result<()>[src]
ⓘImportant traits for IntoIter<'a, V, R>pub fn into_iter<V: Visitor>(self, visitor: &mut V) -> IntoIter<V, R>[src]
ⓘImportant traits for IntoIter<'a, V, R>
Create an iterator over all games.
Errors
- I/O error from the underlying reader.
- Irrecoverable parser errors.
pub fn into_inner(self) -> Chain<Cursor<Buffer>, R>[src]
Gets the remaining bytes in the buffer and the underlying reader.