[−][src]Struct pgn_reader::SanPlus
A San and possible check and checkmate suffixes.
Fields
san: Sansuffix: Option<Suffix>Methods
impl SanPlus[src]
pub fn from_ascii(san: &[u8]) -> Result<SanPlus, ParseSanError>[src]
Parses a SAN and possible check and checkmate suffix.
Errors
Returns ParseSanError if san is not syntactically valid.
pub fn from_move_and_play_unchecked<P>(pos: &mut P, m: &Move) -> SanPlus where
P: Position, [src]
P: Position,
Converts a move to Standard Algebraic Notation including possible check and checkmate suffixes. Also plays the move.
It is the callers responsibility to ensure the move is legal.
Panics
Illegal moves can corrupt the state of the position and may (or may not) panic or cause panics on future calls.
pub fn from_move<P>(pos: P, m: &Move) -> SanPlus where
P: Position, [src]
P: Position,